
/* This file is generated by glib-mkenums, do not modify it. This code is licensed under the same license as the containing project. Note that it links to GLib, so must comply with the LGPL linking clauses. */

#pragma once

            #include <glib-object.h>
            #include <libide-core.h>

            G_BEGIN_DECLS

/* enumerations from "ide-completion-types.h" */

_IDE_EXTERN
GType ide_completion_activation_get_type (void);
#define IDE_TYPE_COMPLETION_ACTIVATION (ide_completion_activation_get_type())

_IDE_EXTERN
GType ide_completion_column_get_type (void);
#define IDE_TYPE_COMPLETION_COLUMN (ide_completion_column_get_type())

/* enumerations from "ide-source-view.h" */

_IDE_EXTERN
GType ide_cursor_type_get_type (void);
#define IDE_TYPE_CURSOR_TYPE (ide_cursor_type_get_type())

_IDE_EXTERN
GType ide_source_view_mode_type_get_type (void);
#define IDE_TYPE_SOURCE_VIEW_MODE_TYPE (ide_source_view_mode_type_get_type())

_IDE_EXTERN
GType ide_source_view_theatric_get_type (void);
#define IDE_TYPE_SOURCE_VIEW_THEATRIC (ide_source_view_theatric_get_type())

_IDE_EXTERN
GType ide_source_view_movement_get_type (void);
#define IDE_TYPE_SOURCE_VIEW_MOVEMENT (ide_source_view_movement_get_type())

_IDE_EXTERN
GType ide_source_scroll_align_get_type (void);
#define IDE_TYPE_SOURCE_SCROLL_ALIGN (ide_source_scroll_align_get_type())

G_END_DECLS

/* Generated data ends here */

