
/* This file is generated by glib-mkenums, do not modify it. This code is licensed under the same license as the containing project. Note that it links to GLib, so must comply with the LGPL linking clauses. */

#pragma once

            #include <glib-object.h>
            #include <libide-core.h>

            G_BEGIN_DECLS

/* enumerations from "ide-build-log.h" */

_IDE_EXTERN
GType ide_build_log_stream_get_type (void);
#define IDE_TYPE_BUILD_LOG_STREAM (ide_build_log_stream_get_type())

/* enumerations from "ide-config.h" */

_IDE_EXTERN
GType ide_build_locality_get_type (void);
#define IDE_TYPE_BUILD_LOCALITY (ide_build_locality_get_type())

/* enumerations from "ide-device-info.h" */

_IDE_EXTERN
GType ide_device_kind_get_type (void);
#define IDE_TYPE_DEVICE_KIND (ide_device_kind_get_type())

/* enumerations from "ide-device.h" */

_IDE_EXTERN
GType ide_device_error_get_type (void);
#define IDE_TYPE_DEVICE_ERROR (ide_device_error_get_type())

/* enumerations from "ide-pipeline-phase.h" */

_IDE_EXTERN
GType ide_pipeline_phase_get_type (void);
#define IDE_TYPE_PIPELINE_PHASE (ide_pipeline_phase_get_type())

/* enumerations from "ide-runtime.h" */

_IDE_EXTERN
GType ide_runtime_error_get_type (void);
#define IDE_TYPE_RUNTIME_ERROR (ide_runtime_error_get_type())

/* enumerations from "ide-test.h" */

_IDE_EXTERN
GType ide_test_status_get_type (void);
#define IDE_TYPE_TEST_STATUS (ide_test_status_get_type())

G_END_DECLS

/* Generated data ends here */

